@@ -1,8 +1,6 @@
-__version__ = "3.0.1"
-__license__ = "MIT"
+from __future__ import annotations
 
-
-from .exceptions import MethodNotAllowed, NotFound, RouterError
+from .exceptions import InvalidMethodError, NotFoundError, RouterError
 from .router import Router
 from .routes import DynamicRoute, Mount, PrefixedRoute, Route
 
@@ -12,7 +10,7 @@ __all__ = (
     "PrefixedRoute",
     "Route",
     "Router",
-    "MethodNotAllowed",
-    "NotFound",
+    "InvalidMethodError",
+    "NotFoundError",
     "RouterError",
 )
